@@ -71,7 +71,7 @@ Ops.fractions <- function(e1, e2)
   fractions(NextMethod(.Generic))
 }
 
-Summary.fractions <- function(x, ...)
+Summary.fractions <- function(x, ..., na.rm)
 {
   x <- unclass(x)
   fractions(NextMethod())
@@ -89,7 +89,7 @@ Summary.fractions <- function(x, ...)
   fractions(NextMethod())
 }
 
-as.character.fractions <- function(x)
+as.character.fractions <- function(x, ...)
     structure(attr(x, "fracs"), dim = dim(x), dimnames = dimnames(x))
 
 as.fractions <- function(x)
