@@ -2,7 +2,7 @@
 #
 # port to R by B. D. Ripley copyright (C) 1998
 #
-#corrections copyright (C) 2000, 3 B. D. Ripley
+#corrections copyright (C) 2000,3,6 B. D. Ripley
 profile.glm <- function(fitted, which = 1:p, alpha = 0.01,
 			maxsteps = 10, del = zmax/5, trace = FALSE, ...)
 {
@@ -12,7 +12,7 @@ profile.glm <- function(fitted, which = 1:p, alpha = 0.01,
     if(is.character(which)) which <- match(which, Pnames)
     summ <- summary(fitted)
     std.err <- summ$coefficients[, "Std. Error"]
-    mf <- update(fitted, method = "model.frame")
+    mf <- model.frame(fitted)
     n <- length(Y <- model.response(mf))
     O <- model.offset(mf)
     if(!length(O)) O <- rep(0, n)
@@ -121,7 +121,7 @@ function(x, colours = 2:3, ...)
     Pnames <- colnames(rng)
     npar <- length(Pnames)
     coefs <- coef(attr(x, "original.fit"))
-    form <- paste(as.character(attr(x, "original.fit")$formula)[c(2, 1, 3)],
+    form <- paste(as.character(formula(attr(x, "original.fit")))[c(2, 1, 3)],
                   collapse = "")
     oldpar <- par(mar = c(0, 0, 0, 0), mfrow = c(1, 1),
                   oma = c(3, 3, 6, 3), las = 1)
